/*
  Demo
  Version: 0.5
  Author:  P. Peters
  Date:    October 13, 2016

  This example code is in the public domain.

*/

// pin definitions
#define ledPin 6          // the pin that the LED is attached to
#define buttonPin 11      // button input pin
#define ldrPin A0         // analog input used for LDR
#define ntcPin A1         // analog input used for NTC
#define fadeAmount 5      // how many steps to fade the led each time

// variables
int brightness = 0;       // how bright the LED currently is
int lastldrValue = 0;     // last LDR sensor value read
int lastntcValue = 0;     // last NTC sensor value read
int lastbuttonValue = 0;  // last button level read
int ldrValue = 0;         // current LDR sensor value read
int ntcValue = 0;         // current NTC sensor value read
int buttonValue = 0;      // current button level read

// the setup routine runs once when you press reset:
void setup()  {
  // declare led pin to be an output:
  pinMode(ledPin, OUTPUT);
  // declare button pin, ntc pin and ldr pin to be input
  pinMode(buttonPin, INPUT);
  pinMode(ldrPin, INPUT);
  pinMode(ntcPin, INPUT);
  // initialize serial communication
  Serial.begin(9600);
}

// the loop routine runs over and over again forever:
void loop() {
  //
  // process sensor values
  //
  processSensors();

  //
  // Read command from serial connection
  //
  while (Serial.available() > 0)
      processCommand(Serial.read());
}


// read sensor values and send the values if any changes were detected
void processSensors() {
    // read sensor values
  buttonValue = digitalRead(buttonPin);
  ldrValue = analogRead(ldrPin);
  ntcValue = analogRead(ntcPin);

  // communicate sensor values if any changed
  if ((lastbuttonValue != buttonValue) || (abs(lastldrValue-ldrValue) > 20) || (abs(lastntcValue-ntcValue) > 4)) {
    // change detected, copy current values to last values
    lastbuttonValue = buttonValue;
    lastldrValue = ldrValue;
    lastntcValue = ntcValue;
    // send values using serial port
    Serial.print(buttonValue);
    Serial.print(",");
    Serial.print(ldrValue);
    Serial.print(",");
    Serial.println(ntcValue);
  }
}

void processCommand(byte cmd) {
  //
  // use value received as LED intensity
  //
  analogWrite(ledPin, cmd);
}

